pub enum UseDefault {
Enabled,
Disabled,
}Expand description
Default value for a USE flag that is not defined by the dependency package
When a package does not define a particular USE flag in its IUSE, the default annotation specifies what value the package manager should assume.
See PMS 8.3.4.
Variants
Enabled
(+) — assume the flag is enabled if not defined by the package.
Disabled
(-) — assume the flag is disabled if not defined by the package.